<template>
  <div class="single-timer">
    <card-group>
      <template v-slot:content>
        <gree-date-picker
          ref="picker"
          class="single-picker"
          :class="{ 'on-off': powType }"
          v-model="currentTime"
          :filter="filter"
          type="time"
          :title="title"
          :min-hour="0"
          :max-hour="24"
          @change="onChange"
          @cancel="onCancel"
          @confirm="onConfirm"
        />
      </template>
    </card-group>
  </div>
</template>

<script>
import { Switch, Check, Icon, DatePicker } from 'gree-ui';
import { mapState, mapMutations, mapGetters, mapActions } from 'vuex';
import dayjs from 'dayjs';
import { types } from '@/store/types';
import CardGroup from '@/components/CardGroup/index';

export default {
  name: 'SingleTimerSet',
  components: {
    [CardGroup.name]: CardGroup,
    [DatePicker.name]: DatePicker,
    [Switch.name]: Switch,
    [Check.name]: Check,
    [Icon.name]: Icon
  },
  data() {
    return {
      addMin: 30,
      addHour: 0,
      addTime: 30,
      currentTime: '00:30'
    };
  },
  computed: {
    ...mapState('control', {
      mac: state => state.mac,
      mainMac: state => state.mainMac,
      TmrOffMinLf: state => state.dataObject.TmrOffMinLf,
      TmrOnMinLf: state => state.dataObject.TmrOnMinLf
    }),
    ...mapGetters(['powType']),
    switchSize() {
      return Math.floor((window['lib'].flexible.rem / 108) * 88);
    },
    performTime() {
      let time = new Date().getTime();
      let result = dayjs(time)
        .add(this.addTime, 'minute')
        .format('hh:mm');
      return result;
    },
    textType() {
      let time = new Date().getTime();
      let result = dayjs(time)
        .add(this.addTime, 'minute')
        .format('HH');
      return result >= 12 ? '下午' : '上午';
    },
    title() {
      return '设备将在' + this.textType + this.performTime + [this.powType ? '关机' : '开机'];
    }
  },
  watch: {},
  methods: {
    ...mapMutations('control', {
      setDataObject: 'SET_DATA_OBJECT',
      setState: 'CONTROL_SET_STATE',
      SetPopup: 'SET_POPUP'
    }),
    ...mapActions({
      sendData: types.SEND_DATA,
      sendCtrl: types.SEND_CTRL
    }),
    onConfirm() {
      this.setDataObject({ MainPopupType: '', SingleTimerSet: 1 });
      const jsonType = this.powType ? 'TmrOffMinLf' : 'TmrOnMinLf';
      const textType = this.powType ? '关机' : '开机';
      this.sendData({ [jsonType]: this.addTime });
      this.setState({ singleTimer: `${this.addHour}小时${this.addMin}分钟后${textType}` });
    },
    onCancel() {
      this.setDataObject({ MainPopupType: '' });
    },
    onChange(picker) {
      this.addHour = parseInt(picker.getValues()[0]);
      this.addMin = parseInt(picker.getValues()[1]);
      this.addTime = this.addHour * 60 + this.addMin;
    },
    filter(type, values) {
      if (type === 'minute') {
        if (this.addHour === 0) {
          return values.filter(value => value == 30);
        } else if (this.addHour === 24) {
          return values.filter(value => value == 0);
        } else return values.filter(value => value % 30 === 0);
      }
      return values;
    },
    // 更新高度
    updateBoxHeight() {
      this.$emit('updateHeight');
    }
  }
};
</script>

<style lang="scss">
.card-group {
  .single-picker {
    background-color: rgba(243, 248, 255, 1);
    width: 100%;
    border-radius: 36px;
    box-shadow: 0 9px 21px 3px rgba(0, 85, 255, 0.05);

    .gree-picker__columns {
      .gree-picker__mask {
        background-image: linear-gradient(180deg, hsla(215, 100%, 98%, 1), hsla(210, 65%, 97%, 0.5)),
          linear-gradient(0deg, hsla(215, 100%, 98%, 1), hsla(210, 65%, 97%, 0.5));
        &::after {
          content: '后开机';
          position: absolute;
          top: 50%;
          left: 50%;
          transform: translateY(-50%);
          margin-left: 26%;
          color: #71acf1;
          font-size: 42px;
          white-space: nowrap;
        }
      }
      .gree-picker-column {
        position: relative;
        &:nth-child(2) {
          margin-right: 20%;
          &::after {
            content: '分';
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translateY(-50%);
            margin-left: 12%;
            color: #71acf1;
            font-size: 56px;
            white-space: nowrap;
          }
        }
        &:nth-child(1) {
          margin-left: 20%;
          &::after {
            content: '时';
            position: absolute;
            top: 50%;
            left: 60%;
            margin-left: 2%;
            transform: translateY(-50%);
            color: #71acf1;
            font-size: 56px;
          }
        }
      }
    }
  }
  .on-off {
    .gree-picker__columns {
      .gree-picker__mask {
        &::after {
          content: '后关机';
          position: absolute;
          top: 50%;
          left: 50%;
          transform: translateY(-50%);
          margin-left: 26%;
          color: #71acf1;
          font-size: 42px;
          white-space: nowrap;
        }
      }
    }
  }
}
</style>
